# kts

`kts` is the first competition-oriented framework for interactive feature engineering and building reproducible pipelines.

## Getting started

To get the latest version of the framework, you can either use `pip` or download the source code via `git clone`:

``` sh
$ pip3 install kts
```
or
``` sh
$ git clone github.com/konodyuk/kts.git
```

The second option is better only if you want to download our example.

After installation you need to initialize your kts project:

``` sh
$ cd project/
$ kts init
```

We highly recommend that you use an empty folder for that, but if you want to use already downloaded data, ensure that it is stored in `project/input` and follow the instructions.

## Example

To get used to kts interface, run the example notebook. It contains a full data processing cycle with kts. Of course, the example is not comprehensive, so don't hesitate to ask [me](https://telegram.me/konodyuk) any questions. 

Leave your bug reports in the issues.
